==> bootstrap-7.0.0-rc.45.tgz: package/tsDist/components/dashboard/shared/Welcome/WelcomePresenter.js <==
import React from 'react';
import { Box } from 'components/elements';
import { formatNumber } from '../../utils';
import { WidgetTitle } from '../WidgetTitle';
import { SessionsCountBox } from './SessionsCountBox';
import { SessionsButtonText } from './SessionsButtonText';
import { SessionButton } from './SessionButton';
import { WelcomeLoader } from './WelcomeLoader';
var getSessionsButton = function (sessionsButtonConfig) {
    var text = sessionsButtonConfig.text, onClick = sessionsButtonConfig.onClick, id = sessionsButtonConfig.id, buttonText = sessionsButtonConfig.buttonText, _a = sessionsButtonConfig.buttonTextCount, buttonTextCount = _a === void 0 ? 0 : _a, _b = sessionsButtonConfig.btnType, btnType = _b === void 0 ? 'primary' : _b;
    return (React.createElement(SessionsCountBox, { text: text, btnType: btnType, onClick: onClick, key: id },
        React.createElement(Box, null,
            React.createElement(SessionsButtonText, { textAlign: "center", fontSize: "18px" }, buttonText),
            React.createElement(SessionsButtonText, { textAlign: "center", fontSize: "88px" }, formatNumber(buttonTextCount))),
        React.createElement(SessionButton, { onClick: onClick, btnType: btnType }, text)));
};
export var WelcomePresenter = function (_a) {
    var loading = _a.loading, error = _a.error, _b = _a.sessionsButtonsConfig, sessionsButtonsConfig = _b === void 0 ? [] : _b, greeting = _a.greeting, subTitle = _a.subTitle;
    var sessionsButtons = sessionsButtonsConfig.map(getSessionsButton);
    var content = error || (React.createElement(React.Fragment, null,
        React.createElement(Box, { floated: "left" },
            React.createElement(WidgetTitle, null, greeting)),
        React.createElement(Box, { floated: "left" },
            React.createElement("span", null, subTitle)),
        React.createElement("br", null),
        React.createElement(Box, { direction: "row", centered: "spaced" }, loading ? React.createElement(WelcomeLoader, { count: 2 }) : sessionsButtons)));
    return React.createElement(Box, { centered: true }, content);
};

==> bootstrap-7.0.2.tgz: package/tsDist/components/dashboard/shared/Welcome/WelcomePresenter.js <==
import React from 'react';
import { Box } from 'components/elements';
import { SessionsButton } from './SessionsButton';
import { SessionsButtonText } from './SessionsButtonText';
import { WelcomeLoader } from './WelcomeLoader';
import { formatNumber } from '../../utils';
import { WidgetTitle } from '../WidgetTitle';
import { WelcomeContainer } from './styles';
var getSessionsButton = function (sessionsButtonConfig) {
    var text = sessionsButtonConfig.text, onClick = sessionsButtonConfig.onClick, id = sessionsButtonConfig.id, buttonText = sessionsButtonConfig.buttonText, _a = sessionsButtonConfig.buttonTextCount, buttonTextCount = _a === void 0 ? 0 : _a, _b = sessionsButtonConfig.btnType, btnType = _b === void 0 ? 'primary' : _b;
    return (React.createElement(SessionsButton, { text: text, btnType: btnType, onClick: onClick, key: id },
        React.createElement(Box, null,
            React.createElement(SessionsButtonText, { fontSize: "18px" }, buttonText),
            React.createElement(SessionsButtonText, { fontSize: "88px" }, formatNumber(buttonTextCount)))));
};
export var WelcomePresenter = function (_a) {
    var loading = _a.loading, error = _a.error, _b = _a.sessionsButtonsConfig, sessionsButtonsConfig = _b === void 0 ? [] : _b, greeting = _a.greeting, subTitle = _a.subTitle;
    var sessionsButtons = sessionsButtonsConfig.map(getSessionsButton);
    var content = error || (React.createElement(WelcomeContainer, null,
        React.createElement(Box, { floated: "left" },
            React.createElement(WidgetTitle, null, greeting)),
        React.createElement(Box, { floated: "left" },
            React.createElement("span", null, subTitle)),
        React.createElement("br", null),
        React.createElement(Box, { direction: "row", centered: "spaced" }, loading ? React.createElement(WelcomeLoader, { count: 2 }) : sessionsButtons)));
    return React.createElement(Box, { centered: true }, content);
};
